@@ -12,14 +12,10 @@ def create_project_structure(project_name: str, project_path: str) -> str:
         base_path = Path(project_path) / project_name
 
     dirs = [
-        "css",
-        "js",
-        "images",
         "assets",
         "assets/css",
         "assets/js",
         "assets/images",
-        "components",
     ]
 
     try:
