@@ -44,8 +44,9 @@ DEFAULT_PROJECT_ROOT = os.path.abspath(
 )
 # 是否自动生成项目子目录（可通过环境变量控制）
 AUTO_CREATE_PROJECT_DIR = os.environ.get("AUTO_CREATE_PROJECT_DIR", "true").lower() == "true"
-# 默认的文件上传URL（可通过环境变量 UPLOAD_URL 覆盖）
-DEFAULT_UPLOAD_URL = os.environ.get("UPLOAD_URL", "https://www.mcpcn.cc/api/fileUploadAndDownload/uploadMcpFile")
+DEFAULT_UPLOAD_URL = os.environ.get(
+    "UPLOAD_URL", "https://www.mcpcn.cc/api/fileUploadAndDownload/uploadMcpFile"
+)
 DEFAULT_MODEL = os.environ.get("WEB_AGENT_MODEL", "qwen3-coder-plus-2025-09-23")
 DEFAULT_BASE_URL = os.environ.get(
     "OPENAI_BASE_URL", "https://dashscope.aliyuncs.com/compatible-mode/v1"
@@ -85,6 +86,38 @@ _CONTEXT_CACHE_BY_ID: dict[str, Dict[str, Any]] = {}
 _CONTEXT_ID_BY_PLAN: dict[str, str] = {}
 
 
+def _resolve_edgeone_deploy_env() -> str:
+    """解析 EdgeOne 自动部署环境，默认 Production。"""
+    env_value = (
+        os.environ.get("EDGEONE_AUTO_DEPLOY_ENV")
+        or os.environ.get("EDGEONE_PAGES_DEPLOY_ENV")
+        or "Production"
+    )
+    return env_value if env_value in {"Production", "Preview"} else "Production"
+
+
+def _should_upload_zip_to_oss() -> bool:
+    """是否在 EdgeOne 部署前上传 ZIP 到 OSS。"""
+    flag = os.environ.get("KEEP_OSS_UPLOAD", "true").strip().lower()
+    return flag not in {"0", "false", "no", "off"}
+
+
+def _extract_zip_url(upload_result: Dict[str, Any]) -> Optional[str]:
+    """从上传结果中提取包含 .zip 的下载地址。"""
+    try:
+        candidates = [
+            upload_result.get("oss_url"),
+            upload_result.get("upload_url"),
+            (upload_result.get("oss_response") or {}).get("url"),
+            upload_result.get("url"),
+        ]
+        for candidate in candidates:
+            if candidate and ".zip" in str(candidate).lower():
+                return candidate
+    except Exception:
+        pass
+    return None
+
 def _job_state_path(job_id: str) -> Path:
     return JOB_STATE_DIR / f"{job_id}.json"
 
@@ -625,6 +658,7 @@ async def execute_plan(
             "project_directory": project_dir,
             "model": agent.model,
             "progress_log": progress_log_path,
+            "deployment_env": _resolve_edgeone_deploy_env(),
             "started_at": time.time(),
             "updated_at": time.time(),
         }
@@ -656,7 +690,9 @@ async def execute_plan(
             "job_id": job_id,
             "plan_id": plan_id,
             "progress_log": progress_log_path,
-            "upload_url": DEFAULT_UPLOAD_URL,
+            "upload_url": None,
+            "web_url": None,
+            "deployment_env": job_info["deployment_env"],
             "message": message,
         }
     except Exception as exc:
@@ -713,29 +749,71 @@ async def _handle_auto_upload(
     if not project_dir:
         return
 
+    upload_target = project_dir
+
+    created_files = (job_info.get("result") or {}).get("created_files") or []
+    for file_path in created_files:
+        if not file_path:
+            continue
+        try:
+            candidate_path = file_path
+            if not os.path.isabs(candidate_path):
+                candidate_path = os.path.join(project_dir, candidate_path)
+            if not os.path.exists(candidate_path):
+                continue
+            candidate_dir = (
+                candidate_path if os.path.isdir(candidate_path) else os.path.dirname(candidate_path)
+            )
+            rel_path = os.path.relpath(candidate_dir, project_dir)
+            if rel_path == "." or rel_path.startswith(".."):
+                continue
+            top_level = rel_path.split(os.sep, 1)[0]
+            top_level_dir = os.path.join(project_dir, top_level)
+            if os.path.isdir(top_level_dir):
+                upload_target = top_level_dir
+                break
+        except Exception:
+            continue
+
     job_info["upload_status"] = "uploading"
     _persist_job_state(job_id)
 
     try:
-        upload_result = await upload_project_to_mcp_server(
-            folder_path=project_dir,
-            upload_url=DEFAULT_UPLOAD_URL,
-        )
+        upload_func = getattr(upload_project_to_mcp_server, "fn", None)
+        if not callable(upload_func):
+            raise RuntimeError("upload_project_to_mcp_server 缺少可调用实现")
+
+        upload_result = await upload_func(folder_path=upload_target)
 
         job_info["upload_result"] = upload_result
         job_info["upload_status"] = upload_result.get("status")
+        if upload_result.get("deployment_env"):
+            job_info["deployment_env"] = upload_result["deployment_env"]
 
         if upload_result.get("status") == "success":
-            job_info["website_url"] = upload_result.get("url")
+            zip_url = _extract_zip_url(upload_result)
+            web_url = (
+                upload_result.get("web_url")
+                or (upload_result.get("result") or {}).get("url")
+            )
+            if zip_url:
+                job_info["upload_url"] = zip_url
+            if web_url:
+                job_info["web_url"] = web_url
             job_info["upload_completed_at"] = time.time()
+            job_info["uploaded_directory"] = upload_target
 
             if progress_log_path:
                 upload_event = {
                     "timestamp": time.time(),
                     "type": "upload_completed",
                     "status": "success",
-                    "website_url": upload_result.get("url"),
+                    "web_url": web_url,
+                    "upload_url": zip_url,
+                    "oss_url": zip_url,
+                    "deployment_env": job_info.get("deployment_env"),
                     "message": upload_result.get("message"),
+                    "uploaded_directory": upload_target,
                 }
                 try:
                     with open(progress_log_path, "a", encoding="utf-8") as log_file:
@@ -1095,8 +1173,11 @@ async def get_progress(
                 "project_directory",
                 "model",
                 "upload_status",
-                "website_url",
+                "upload_url",
+                 "web_url",
+                 "deployment_env",
                 "upload_completed_at",
+                "uploaded_directory",
             ]
             job_snapshot = {
                 k: job_info.get(k) for k in snapshot_keys if job_info.get(k) is not None
@@ -1131,15 +1212,17 @@ async def get_progress(
 async def upload_project_to_mcp_server(
     folder_path: str,
 ) -> Dict[str, Any]:
-    """将项目文件夹打包成ZIP并上传到MCP服务器。
+    """将项目文件夹打包成ZIP并上传到 EdgeOne Pages（自动部署流程）。
 
     参数说明：
     - folder_path: 项目文件夹的绝对路径
 
     返回值：
     - status: 上传状态 ("success" 或 "error")
-    - url: 上传成功后返回的文件访问URL
-    - zip_path: 临时ZIP文件路径（用于调试）
+    - web_url: 部署成功后返回的 EdgeOne 访问地址
+    - deployment_env: 部署环境（Production/Preview）
+    - deployment_result: EdgeOne 原始部署结果
+    - deployment_logs: 部署日志
     - message: 状态信息
     """
     try:
@@ -1150,6 +1233,12 @@ async def upload_project_to_mcp_server(
         if not os.path.isdir(folder_path):
             return {"status": "error", "message": f"路径不是文件夹: {folder_path}"}
 
+        if not os.getenv("EDGEONE_PAGES_API_TOKEN"):
+            return {
+                "status": "error",
+                "message": "缺少 EDGEONE_PAGES_API_TOKEN 环境变量，无法执行 EdgeOne 部署",
+            }
+
         # 创建临时ZIP文件
         project_name = os.path.basename(folder_path.rstrip("/"))
         temp_dir = tempfile.gettempdir()
@@ -1174,52 +1263,85 @@ async def upload_project_to_mcp_server(
                 "message": f"ZIP文件过大: {zip_size / 1024 / 1024:.1f}MB，超过50MB限制",
             }
 
-        # 上传文件
-        async with aiohttp.ClientSession() as session:
-            with open(zip_path, "rb") as f:
-                data = aiohttp.FormData()
-                data.add_field(
-                    "file", f, filename=zip_filename, content_type="application/zip"
-                )
+        oss_url: Optional[str] = None
+        oss_response: Optional[Dict[str, Any]] = None
+        if _should_upload_zip_to_oss():
+            async with aiohttp.ClientSession() as session:
+                with open(zip_path, "rb") as f:
+                    data = aiohttp.FormData()
+                    data.add_field(
+                        "file", f, filename=zip_filename, content_type="application/zip"
+                    )
 
-                async with session.post(DEFAULT_UPLOAD_URL, data=data) as response:
-                    response_text = await response.text()
-
-                    if response.status != 200:
-                        return {
-                            "status": "error",
-                            "message": f"上传失败，HTTP {response.status}: {response_text}",
-                        }
-
-                    # 解析响应JSON
-                    try:
-                        result = json.loads(response_text)
-                        if result.get("code") == 0 and result.get("data", {}).get(
-                            "url"
-                        ):
-                            # 清理临时文件
-                            try:
-                                os.remove(zip_path)
-                            except:
-                                pass
+                    async with session.post(DEFAULT_UPLOAD_URL, data=data) as response:
+                        response_text = await response.text()
 
+                        if response.status != 200:
                             return {
-                                "status": "success",
-                                "url": result["data"]["url"],
-                                "message": f"项目 '{project_name}' 上传成功",
-                                "zip_size": f"{zip_size / 1024:.1f}KB",
+                                "status": "error",
+                                "message": f"OSS 上传失败，HTTP {response.status}: {response_text}",
                             }
+
+                        try:
+                            result = json.loads(response_text)
+                        except json.JSONDecodeError:
+                            return {
+                                "status": "error",
+                                "message": f"OSS 上传响应解析失败: {response_text}",
+                            }
+
+                        upload_data = result.get("data") or {}
+                        oss_response = upload_data
+                        if result.get("code") == 0 and upload_data.get("url"):
+                            oss_url = upload_data["url"]
                         else:
                             return {
                                 "status": "error",
-                                "message": f"上传失败: {result.get('msg', '未知错误')}",
+                                "message": f"OSS 上传失败: {result.get('msg', '未知错误')}",
                                 "response": response_text,
                             }
-                    except json.JSONDecodeError:
-                        return {
-                            "status": "error",
-                            "message": f"响应解析失败: {response_text}",
-                        }
+
+        # 导入 EdgeOne 部署工具
+        from htmlgen_mcp.agents.web_tools.edgeone_deploy import (
+            deploy_folder_or_zip_to_edgeone,
+        )
+
+        deployment_env = _resolve_edgeone_deploy_env()
+
+        # 将 ZIP 包部署到 EdgeOne（使用线程避免阻塞事件循环）
+        result_json = await asyncio.to_thread(
+            deploy_folder_or_zip_to_edgeone, zip_path, deployment_env
+        )
+
+        try:
+            deploy_result = json.loads(result_json)
+        except json.JSONDecodeError:
+            return {
+                "status": "error",
+                "message": f"EdgeOne 返回数据解析失败: {result_json}",
+            }
+
+        edgeone_result = deploy_result.get("result") or {}
+        web_url = edgeone_result.get("url")
+
+        response: Dict[str, Any] = {
+            "status": "success",
+            "web_url": web_url,
+            "oss_url": oss_url,
+            "oss_response": oss_response,
+            "deployment_env": deployment_env,
+            "deployment_result": edgeone_result,
+            "deployment_logs": deploy_result.get("deployment_logs"),
+            "zip_size": f"{zip_size / 1024:.1f}KB",
+            "message": f"项目 '{project_name}' 已部署到 EdgeOne ({deployment_env})",
+        }
+        if oss_url:
+            response["upload_url"] = oss_url
+
+        if not web_url:
+            response["message"] += "，但未获取到访问链接"
+
+        return response
 
     except Exception as exc:
         # 清理临时文件
@@ -1229,11 +1351,42 @@ async def upload_project_to_mcp_server(
             except:
                 pass
 
-        return {
+        error_message = str(exc)
+        try:
+            # EdgeOne 部署错误通常是 JSON 字符串
+            if error_message.startswith("{"):
+                error_data = json.loads(error_message)
+                error_response = {
+                    "status": "error",
+                    "message": error_data.get("error", error_message),
+                    "deployment_logs": error_data.get("deployment_logs", ""),
+                    "traceback": traceback.format_exc(),
+                }
+                if "oss_url" in locals() and oss_url:
+                    error_response["upload_url"] = oss_url
+                if "oss_response" in locals() and oss_response:
+                    error_response["oss_response"] = oss_response
+                return error_response
+        except Exception:
+            pass
+
+        error_response = {
             "status": "error",
-            "message": str(exc),
+            "message": error_message,
             "traceback": traceback.format_exc(),
         }
+        if "oss_url" in locals() and oss_url:
+            error_response["upload_url"] = oss_url
+        if "oss_response" in locals() and oss_response:
+            error_response["oss_response"] = oss_response
+        return error_response
+    finally:
+        # 确保清理临时ZIP文件
+        if "zip_path" in locals() and os.path.exists(zip_path):
+            try:
+                os.remove(zip_path)
+            except:
+                pass
 
 
 @mcp.tool()
